/**
 * $Id: AbstractIoAspect.aj,v 1.1 2011/12/22 17:15:08 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 01.04.2009 by oliver (ob@aosd.de)
 */
package patterntesting.check.ct;

/**
 * Since JDK 1.1 you should use the Writer and Reader classes and not the
 * Stream classes. So you should get a warning if you try to use the old
 * Stream classes. The only exception may be the PrintStream class because
 * System.out and System.err depends on it.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 01.04.2009
 * @version $Revision: 1.1 $
 */
public abstract aspect AbstractIoAspect {

    /**
     * Specify what the application code is that should be subject to the
     * pattern test.
     * <br/>
     * Ex: <code>pointcut applicationCode(): within(patterntesting.sample.*)</code>
     */
    public abstract pointcut applicationCode();

    pointcut newStream() :
        call(public java.io.*Stream.new(..));

    declare warning : newStream() && applicationCode() :
        "don't use Stream class - use Reader or Writer";

}

/**
 * $Log: AbstractIoAspect.aj,v $
 * Revision 1.1  2011/12/22 17:15:08  oboehm
 * directory structure adapted to preferences of maven-aspectj-plugin
 *
 * Revision 1.1  2010/01/05 16:44:14  oboehm
 * begin with 1.0
 *
 * Revision 1.3  2009/12/20 17:30:35  oboehm
 * trailing spaces removed
 *
 * Revision 1.2  2009/09/26 12:36:07  oboehm
 * javadocs completed with the help of JAutodoc
 *
 * Revision 1.1  2009/04/08 19:49:25  oboehm
 * the use of stream classes gives now a warning
 *
 * $Source: /cvsroot/patterntesting/PatternTesting10/patterntesting-check-ct/src/main/aspect/patterntesting/check/ct/AbstractIoAspect.aj,v $
 */
